Authors
=======
The following have contributed to the development, maintenance, and testing of BEL Commons:

Maintainers
-----------
- `Charles Tapley Hoyt <https://github.com/cthoyt>`_
- `Daniel Domingo Fernández <https://github.com/ddomingof>`_

Support
-------
- André Gemünd
